Tornado Handlers — BCI-Framework documentation

# Tornado Handlers

This handlers are used to configure the Stimuli Delivery.

class `bci_framework.extensions.stimuli_delivery.tornado_handlers.` `ModeHandler`(application: tornado.web.Application, request: tornado.httputil.HTTPServerRequest, **kwargs: Any)

  /mode endpoint to differentiate between Data analysis and Stimuli Delivery.

class `bci_framework.extensions.stimuli_delivery.tornado_handlers.` `WSHandler`(*args, **kwargs)

  WebSockets is the way to comunicate between dashboard and presentations.

  `bci_annotation`(**kwargs)

    Use kafka to stream annotations.

  `bci_feed`(**kwargs)

    Call the same method in all clients.

  `bci_marker`(**kwargs)

    Use kafka to stream markers.

  `bci_register`(**kwargs)

    Register clients.

  `on_message`(message: json)

    Input messages are methods reference with arguments.

    The callable are defined with a bci_ prefix in the methods names.

    Parameters

      message – json string with method name and key words arguments.